Documentation
¶
Index ¶
- Variables
- func WithConsumerArgs(config ConsumerArgs) consumerOption
- func WithConsumerConfig(config CreateConsumerConfig) consumerOption
- func WithHttpConsumer() consumerOption
- type BindQueueByExgConfig
- type ConnectConfig
- type Consumer
- type ConsumerArgs
- type CreateConsumerConfig
- type CreateExchangeConfig
- type CreateQueueConfig
- type Msg
- type Producer
- type ProducerInitConfig
- type Rmq
- func (rmq *Rmq) BindQueueByExchange(config BindQueueByExgConfig) error
- func (rmq *Rmq) Close() error
- func (rmq *Rmq) Connect(config ConnectConfig) error
- func (rmq *Rmq) CreateChannel() (c *amqp.Channel, err error)
- func (rmq *Rmq) CreateExchange(config CreateExchangeConfig) error
- func (rmq *Rmq) CreateQueue(config CreateQueueConfig) (q *amqp.Queue, err error)
- func (rmq *Rmq) ReceiveMessages() <-chan []byte
- type RmqOption
- type SendMsg
Constants ¶
This section is empty.
Variables ¶
var ExchangeType = exchangeType{}
var Exchanges = exchanges{}
Functions ¶
func WithConsumerArgs ¶ added in v1.1.0
func WithConsumerArgs(config ConsumerArgs) consumerOption
Consumer
func WithConsumerConfig ¶ added in v1.1.0
func WithConsumerConfig(config CreateConsumerConfig) consumerOption
func WithHttpConsumer ¶ added in v1.1.0
func WithHttpConsumer() consumerOption
Make able to run in other thread when init Consumer It can be used if need to run rmq service with http
Types ¶
type BindQueueByExgConfig ¶
type Consumer ¶ added in v1.1.0
type Consumer struct {
// contains filtered or unexported fields
}
func NewConsumer ¶ added in v1.1.0
func (*Consumer) AddTopicsFuncs ¶ added in v1.1.0
type ConsumerArgs ¶ added in v1.1.0
type CreateConsumerConfig ¶
type CreateExchangeConfig ¶
type CreateQueueConfig ¶
type Producer ¶ added in v1.1.0
type Producer struct {
// contains filtered or unexported fields
}
func NewProducer ¶ added in v1.1.0
type ProducerInitConfig ¶ added in v1.1.0
type Rmq ¶
type Rmq struct {
// contains filtered or unexported fields
}
func (*Rmq) BindQueueByExchange ¶
func (rmq *Rmq) BindQueueByExchange(config BindQueueByExgConfig) error
func (*Rmq) Connect ¶
func (rmq *Rmq) Connect(config ConnectConfig) error
func (*Rmq) CreateExchange ¶
func (rmq *Rmq) CreateExchange(config CreateExchangeConfig) error
func (*Rmq) CreateQueue ¶
func (rmq *Rmq) CreateQueue(config CreateQueueConfig) (q *amqp.Queue, err error)
func (*Rmq) ReceiveMessages ¶ added in v1.3.2
Only read access
Click to show internal directories.
Click to hide internal directories.